@@ -5,7 +5,7 @@ from multiselectfield import MultiSelectField
 
 from django.conf import settings
 from django.utils import timezone
-from django.utils.translation import ugettext as _
+from django.utils.translation import ugettext_lazy as _
 from django.db import models
 from django.contrib.sites.models import Site
 
